@@ -36,11 +36,11 @@ namespace internal
 {
 
 /** Implementation of the signal interface.
- * signal_impl manages a list of slots. When a slot becomes
- * invalid (because some referred object dies), notify() is executed.
- * notify() either calls slots_.erase() directly or defers the execution of
- * erase() to sweep() when the signal is being emitted. sweep() removes all
- * invalid slots from the list.
+ * signal_impl manages a list of slots. When a slot becomes invalid (because some
+ * referred object dies), notify_self_and_iter_of_invalidated_slot() is executed.
+ * notify_self_and_iter_of_invalidated_slot() either calls slots_.erase() directly
+ * or defers the execution of erase() to sweep() when the signal is being emitted.
+ * sweep() removes all invalid slots from the list.
  */
 struct SIGC_API signal_impl
  : public std::enable_shared_from_this<signal_impl>
@@ -143,12 +143,6 @@ struct SIGC_API signal_impl
    */
   iterator_type insert(iterator_type i, slot_base&& slot_);
 
-  /** Removes the slot at the given position from the list of slots.
-   * @param i An iterator pointing to the slot to be removed.
-   * @return An iterator pointing to the slot in the list after the one removed.
-   */
-  iterator_type erase(iterator_type i);
-
   /// Removes invalid slots from the list of slots.
   void sweep();
 
@@ -184,7 +178,7 @@ struct SIGC_API signal_impl_exec_holder
   /** Increments the execution counter of the parent sigc::signal_impl object.
    * @param sig The parent sigc::signal_impl object.
    */
-  inline signal_impl_exec_holder(signal_impl* sig) noexcept
+  inline explicit signal_impl_exec_holder(signal_impl* sig) noexcept
   : sig_(sig)
   {
     sig_->reference_exec();
@@ -382,13 +376,6 @@ protected:
    */
   iterator_type insert(iterator_type i, slot_base&& slot_);
 
-  /** Removes the slot at the given position from the list of slots.
-   * Note that this function does not work during signal emission!
-   * @param i An iterator pointing to the slot to be removed.
-   * @return An iterator pointing to the slot in the list after the one removed.
-   */
-  iterator_type erase(iterator_type i);
-
   /** Returns the signal_impl object encapsulating the list of slots.
    * @return The signal_impl object encapsulating the list of slots.
    */
